/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#include "fileptriosystem.h"
#include "lineinput.h"
#include <string.h>

#include "debugnew.h"

namespace shellp
{

FilePtrIOSystem::FilePtrIOSystem()
{
	fi = 0;
	fo = 0;
}

FilePtrIOSystem::FilePtrIOSystem(FILE *pInput, FILE *pOutput)
{
	fi = pInput;
	fo = pOutput;
}

FilePtrIOSystem::~FilePtrIOSystem()
{
}

bool FilePtrIOSystem::readInputLineInternal(std::string &line)
{
	if (fi == 0)
	{
		setErrorString("Not file was opened for reading");
		return false;
	}
	return ReadInputLine(fi, line);
}

void FilePtrIOSystem::writeInputPrefix(const std::string &prefix)
{
	if (fo != 0)
		fprintf(fo,"%s",prefix.c_str());
}

void FilePtrIOSystem::writeOutputLine(const std::string &line, bool newline)
{
	if (fo == 0)
		return;

	fprintf(fo,"%s",line.c_str());
	if (newline)
		fprintf(fo,"\n");
	else
		fprintf(fo,"\r");
	fflush(fo);
}

} // end namespace

