/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#include "historylineedit.h"
#include <QKeyEvent>
#include <iostream>

namespace shellp
{

HistoryLineEdit::HistoryLineEdit(QWidget *pParent) : QLineEdit(pParent)
{
	m_histPos = 0;
}

HistoryLineEdit::~HistoryLineEdit()
{
}

void HistoryLineEdit::keyPressEvent(QKeyEvent *event)
{
	if(event->key() == Qt::Key_Up)
	{
		if (m_histPos > 0)
		{
			if (m_histPos == m_history.size())
				m_buffer = text().toStdString();

			m_histPos--;

			std::string line = m_history[m_histPos];
			
			setText(QString(line.c_str()));
		}
	}
	else if (event->key() == Qt::Key_Down)
	{
		if (m_histPos < m_history.size())
		{
			m_histPos++;

			std::string line;

			if (m_histPos == m_history.size())
				line = m_buffer;
			else
				line = m_history[m_histPos];

			setText(QString(line.c_str()));
		}
	}
	else
	{
		if (event->key() == Qt::Key_Enter || event->key() == Qt::Key_Return)
		{
			QString line = text();

			if (line.length() > 0)
			{
				m_history.push_back(line.toStdString());
				m_histPos = m_history.size();
			}
		}
		QLineEdit::keyPressEvent(event);
	}
}

} // end namespace
