/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#ifndef SHELLP_IOSYSTEM_H

#define SHELLP_IOSYSTEM_H

#include "shellconfig.h"
#include <errut/errorbase.h>
#include <string>
#include <vector>
#include <list>

namespace shellp
{

class SHELLP_IMPORTEXPORT IOSystem : public errut::ErrorBase
{
protected:
	IOSystem() 									{ m_echo = true; }
public:
	virtual ~IOSystem() 								{ }

	bool echo() const								{ return m_echo; }
	void setEcho(bool f)								{ m_echo = f; }

	bool readInputLine(const std::string &prefix, std::string &line);
	virtual void writeOutputLine(const std::string &line, bool newline = true)	{ }
	virtual void setPercentageFeedback(double pct);

	virtual bool supports2DPlot() const						{ return false; }
	virtual bool supports3DPlot() const						{ return false; }
	virtual bool plot2D(int id, const std::string &title,
			    const std::string &xLabel, const std::string &yLabel,
			    const std::vector<double> &xPoints, const std::vector<double> &yPoints,
			    bool forceShow = true);
	virtual bool plot3D(int id, const std::string &title, 
			    const std::string &xLabel, const std::string &yLabel,
			    const std::string &zLabel,
			    double xOff, double yOff, double xDdist, double yDist,
			    double xMultiplier, double yMultiplier, double zMultiplier,
			    const std::vector<double> &data, int numX, int numY, bool forceShow = true);

	virtual void writeStatusLine(const std::string &str)				{ writeOutputLine(str, true); }

	void print(const char *format, ...);
	void printNoNewLine(const char *format, ...);

	static void splitLine(const std::string &line, std::vector<std::string> &args);

	void flushExtraInputLines()							{ m_extraInputLines.clear(); }
	void insertExtraInputLine(const std::string &line)				{ m_extraInputLines.push_front(line); }
	void appendExtraInputLine(const std::string &line)				{ m_extraInputLines.push_back(line); }
private:
	virtual bool readInputLineInternal(std::string &line);
	virtual void writeInputPrefix(const std::string &prefix)			{ }

	std::list<std::string> m_extraInputLines;
	bool m_echo;
};

} // end namespace

#endif // SHELLP_IOSYSTEM_H

