/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#ifndef SHELLP_SHELL2DPLOTWINDOW_H

#define SHELLP_SHELL2DPLOTWINDOW_H

#include <QWidget>
#include <string>
#include <vector>

class QwtPlot;
class QwtPlotCurve;

namespace shellp
{

class Shell2DPlotRequest
{
public:
	Shell2DPlotRequest(int id, const std::string &title, const std::string &xLabel,
			   const std::string &yLabel, const std::vector<double> &xPoints,
			   const std::vector<double> &yPoints, bool forceShow)
	{
		m_id = id;
		m_title = title;
		m_xLabel = xLabel;
		m_yLabel = yLabel;
		m_xPoints = xPoints;
		m_yPoints = yPoints;
		m_forceShow = forceShow;
	}

	~Shell2DPlotRequest()
	{
	}

	const std::string &getTitle() const						{ return m_title; }
	const std::string &getXLabel() const						{ return m_xLabel; }
	const std::string &getYLabel() const						{ return m_yLabel; }
	const std::vector<double> &getXPoints() const					{ return m_xPoints; }
	const std::vector<double> &getYPoints() const					{ return m_yPoints; }
	int getID() const								{ return m_id; }
	bool getForceShow() const							{ return m_forceShow; }
private:
	int m_id;
	std::string m_title, m_xLabel, m_yLabel;
	std::vector<double> m_xPoints, m_yPoints;
	bool m_forceShow;
};

class Shell2DPlotWindow : public QWidget
{
	Q_OBJECT
public:
	Shell2DPlotWindow(QWidget *pParent = 0);
	~Shell2DPlotWindow();

	void processRequest(Shell2DPlotRequest *pRequest);
public slots:
	void toggleLogLinear();
	void togglePixelsOrPhysical();
private:
	void plotCurrentRequest();

	Shell2DPlotRequest *m_pRequest;
	QwtPlot *m_pPlot;
	QwtPlotCurve *m_pPlotCurve;
	bool m_log, m_plotPixels;
};

} // end namespace

#endif // SHELLP_SHELL2DPLOTWINDOW_H

