/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#include "shellcmdboolarg.h"

#include "debugnew.h"

namespace shellp
{

ShellCmdBoolArg::ShellCmdBoolArg(const std::string &argName) : ShellCmdArg(Bool, argName)
{
	m_val = true;
}

ShellCmdBoolArg::ShellCmdBoolArg(const std::string &argName, const std::string &defaultValue) : ShellCmdArg(Bool, argName, defaultValue)
{
	m_val = true;
}

ShellCmdBoolArg::~ShellCmdBoolArg()
{
}

bool ShellCmdBoolArg::parse(const std::string &arg)
{
	if (arg == std::string("true"))
		m_val = true;
	else if (arg == std::string("yes"))
		m_val = true;
	else if (arg == std::string("false"))
		m_val = false;
	else if (arg == std::string("no"))
		m_val = false;
	else
	{
		setErrorString("Expecting yes, no, true or false");
		return false;
	}
	return true;
}

} // end namespace
