/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#include "shellcmdrealarg.h"
#include "shellinstance.h"
#include "iosystem.h"
#include <stdlib.h>

#include "debugnew.h"

namespace shellp
{

ShellCmdRealArg::ShellCmdRealArg(const std::string &name, int unitID) : ShellCmdArg(Real, name)
{
	m_usemin = false;
	m_usemax = false;
	m_val = 0;
	m_unitID = unitID;
}

ShellCmdRealArg::ShellCmdRealArg(const std::string &name, const std::string &defaultValue, int unitID) : ShellCmdArg(Real, name, defaultValue)
{
	m_usemin = false;
	m_usemax = false;
	m_val = 0;
	m_unitID = unitID;
}

ShellCmdRealArg::~ShellCmdRealArg()
{
}

bool ShellCmdRealArg::parse(const std::string &arg)
{
	double value;
	const char *nptr;
	char *endptr;
	ShellInstance *pInst = ShellInstance::getInstance();
	
	nptr = arg.c_str();
	value = strtod(nptr,&endptr);

	if (*nptr != '\0')
	{
		if (*endptr != '\0')
		{
			// Not a simple number, check if the parser can handle this

			if (!pInst->evaluateExpression(arg, value))
			{
				setErrorString(std::string("Not a simple real number and math parser cannot parse it: ") + pInst->getErrorString());
				return false;
			}
		}
	}

	if (m_unitID >= 0)
	{
		double multiplier = pInst->getUnitMultiplier(m_unitID);
		value *= multiplier;
	}

	if (m_usemin && value < m_minval)
	{
		setErrorString("Value is smaller than the minimum value");
		return false;
	}
	if (m_usemax && value > m_maxval)
	{
		setErrorString("Value is larger than the maximum value");
		return false;
	}
	
	m_val = value;
	return true;
}

std::string ShellCmdRealArg::getUnitName() const
{
	ShellInstance *pInst = ShellInstance::getInstance();
	std::string name;

	if (m_unitID < 0)
		return std::string("");

	if (!pInst->getUnitName(m_unitID, name))
		return std::string("UNKNOWN UNIT ID");
	return name;
}

} // end namespace
