/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#ifndef SHELLP_SIGNALWAITER_H

#define SHELLP_SIGNALWAITER_H

#include <jthread/jmutex.h>
#if !defined(WIN32) && !defined(_WIN32_WCE)
	#include <pthread.h>
#endif // !WIN32 && !_WIN32_WCE

namespace shellp
{

class SignalWaiter
{
public:
	SignalWaiter();
	~SignalWaiter();
	
	bool init();
	void destroy();

	bool waitForSignal();
	bool signal();

	bool clearSignalBuffers();
	bool isInit()								{ return m_init; }
private:
#ifndef WIN32
	pthread_cond_t m_cond;
	pthread_mutex_t m_mutex;
#else
	HANDLE m_eventObject;
#endif // WIN32
	bool m_init;
	jthread::JMutex m_countMutex,m_waitMutex;
	int m_count;
	bool m_isWaiting;
};

} // end namespace

#endif // SHELLP_SIGNALWAITER_H

